@@ -20,7 +20,7 @@ setMethod("elmt", "EL", function(object,
   if (is.null(control)) {
     control <- getControlEL(object)
   } else {
-    stopifnot("Invalid `control` specified." = is(control, "ControlEL"))
+    assert_class(control, "ControlEL")
   }
   h <- validate_hypotheses(rhs, lhs, p, pnames)
   colnames(h$l) <- pnames
